pub fn print_all()Expand description
Displays all configuration settings in a formatted table.
This function uses the schema to dynamically generate the display, so it automatically includes any new fields added to the schema.
pub fn print_all()Displays all configuration settings in a formatted table.
This function uses the schema to dynamically generate the display, so it automatically includes any new fields added to the schema.